{% for master in bare.masters -%}
{{ master.hostname }} ansible_host={{ master.ip }} ansible_ssh_private_key_file='keys/{{ master.hostname }}/private_key'
{% endfor -%}
{% for node in bare.nodes -%}
{{ node.hostname }} ansible_host={{ node.ip }} ansible_ssh_private_key_file='keys/{{ node.hostname }}/private_key'
{% endfor %}
[opendc:children]
opendc-masters
opendc-nodes
etcd
opendc-ca
fileserver

[opendc:vars]
ansible_ssh_user=opendc
ansible_connection=ssh

[opendc-masters]
{% for master in bare.masters -%}
{{ master.hostname }}
{% endfor %}
[opendc-nodes]
{% for node in bare.nodes -%}
{{ node.hostname }}
{% endfor %}
[etcd]
{% for etcd in bare.etcd -%}
{{ etcd }}
{% endfor %}
[fileserver]
{{ bare.fileserver[0] }}

[opendc-ca]
{{ bare.opendc_ca[0] }}
